==> kernel-0.9.1.5.8.3.10-sources.jar: voxeet/com/sdk/core/VoxeetHttp.java <==
package voxeet.com.sdk.core;

import android.app.Application;
import android.provider.Settings;

import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.common.base.Predicate;
import com.google.common.collect.Iterables;
import com.google.common.collect.Lists;
import com.google.firebase.iid.FirebaseInstanceId;

import java.io.IOException;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

import okhttp3.Authenticator;
import okhttp3.Cookie;
import okhttp3.CookieJar;
import okhttp3.HttpUrl;
import okhttp3.Interceptor;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.Route;
import okhttp3.logging.HttpLoggingInterceptor;
import retrofit2.Retrofit;
import retrofit2.adapter.rxjava.RxJavaCallAdapterFactory;
import rx.Observable;
import rx.Subscriber;
import rx.android.schedulers.AndroidSchedulers;
import rx.schedulers.Schedulers;
import voxeet.com.sdk.converter.JacksonConverterFactory;
import voxeet.com.sdk.core.network.IVoxeetRService;
import voxeet.com.sdk.json.GrandTypeEvent;
import voxeet.com.sdk.json.UserInfo;
import voxeet.com.sdk.models.TokenResponse;
import voxeet.com.sdk.models.UserTokenResponse;
import voxeet.com.sdk.networking.DeviceType;
import voxeet.com.sdk.utils.Auth64;

/**
 * Created by Romain Benmansour on 4/15/16.
 */
public class VoxeetHttp {

    private static final String TAG = VoxeetHttp.class.getSimpleName();
    private final VoxeetSdkTemplate sdk;

    /**
     * The Service.
     */
    protected IVoxeetRService service;

    /**
     * The Token response.
     */
    protected TokenResponse tokenResponse;

    private Application appContext;

    private String serverUrl;

    private String serverPort;

    /**
     * The Retrofit.
     */
    public Retrofit retrofit;

    private OkHttpClient client;

    private String appId;

    private String password;

    private VoxeetServiceListener listener;

    private boolean debug = false;

    private final HashMap<String, List<Cookie>> cookieStore = new HashMap<>();

    /**
     * Instantiates a new Voxeet http.
     *
     * @param appContext the Application Context
     * @param sdk
     * @param appId      the app id
     * @param password   the password
     * @param listener   the listener
     */
    private VoxeetHttp(Application appContext, VoxeetSdkTemplate sdk, String serverUrl, String serverPort, String appId, String password, VoxeetServiceListener listener, boolean debug) {

        this.sdk = sdk;
        this.tokenResponse = null;
        this.serverUrl = serverUrl;
        this.serverPort = serverPort;
        this.appContext = appContext;

        this.debug = debug;


        this.listener = listener;

        this.appId = appId;

        this.password = password;

        this.initClient();

        this.initRetrofit();

        this.initService();
    }

    /**
     * Overrode retrofit client.
     */
    private void initClient() {
        //HttpLoggingInterceptor interceptor = new HttpLoggingInterceptor();
        //interceptor.setLevel(HttpLoggingInterceptor.Level.BODY);

        OkHttpClient.Builder builder = new OkHttpClient.Builder()
                .cookieJar(new CookieJar() {

                    @Override
                    public void saveFromResponse(HttpUrl url, List<Cookie> cookies) {
                        String base = url.scheme() + "://" + url.host() + ":" + url.port();

                        cookieStore.put(base, Lists.<Cookie>newArrayList(Iterables.filter(cookies, new Predicate<Cookie>() {
                            @Override
                            public boolean apply(Cookie input) {
                                return input != null && !input.value().equalsIgnoreCase("deleted") && new Date().before(new Date(input.expiresAt()));
                            }
                        })));
                    }

                    @Override
                    public List<Cookie> loadForRequest(HttpUrl url) {
                        String base = url.scheme() + "://" + url.host() + ":" + url.port();

                        List<Cookie> cookies = cookieStore.get(base);

                        return cookies != null ? cookies : new ArrayList<Cookie>();
                    }
                })
                .addNetworkInterceptor(new Interceptor() {
                    @Override
                    public Response intercept(Chain chain) throws IOException {
                        try {
                            if (tokenResponse == null) {
                                return chain.proceed(chain.request());
                            }


                            return chain.proceed(chain.request().newBuilder().addHeader("Authorization", "bearer " + tokenResponse.getToken()).build());
                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                        return null;
                    }
                })
                .authenticator(new Authenticator() {
                    @Override
                    public Request authenticate(Route route, Response response) throws IOException {
                        try {
                            Observable<TokenResponse> token = service.getToken(Auth64.serialize(appId, password), new GrandTypeEvent("client_credentials"));

                            tokenResponse = token.toBlocking().single();
                        } catch (Exception e) {
                            throw new IllegalStateException("Invalid credentials");
                        }

                        return response.request().newBuilder().addHeader("Authorization", "bearer " + tokenResponse.getToken()).build();
                    }
                })
                .retryOnConnectionFailure(true)
                .readTimeout(5, TimeUnit.SECONDS)
                .writeTimeout(5, TimeUnit.SECONDS);

        //if (this.debug) {
        //    builder = builder.addInterceptor(interceptor);
        //}

        client = builder.build();
    }

    private void initRetrofit() {

        retrofit = new Retrofit.Builder()
                .addCallAdapterFactory(RxJavaCallAdapterFactory.create())
                .addConverterFactory(JacksonConverterFactory.create(new ObjectMapper().disable(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES)))
                .baseUrl(getBuiltServerUrl())
                .client(client)
                .build();
    }

    private void initService() {
        service = retrofit.create(IVoxeetRService.class);
    }

    /**
     * Identify. Similar to a login
     *
     * @param userInfo the user info
     */
    public void identify(UserInfo userInfo) {

        userInfo.setDeviceIdentifier(Settings.Secure.getString(appContext.getContentResolver(), Settings.Secure.ANDROID_ID));

        if (FirebaseController.getInstance().isTokenUploadAllowed()) {
            String token = FirebaseController.getInstance().getToken();

            if(token != null) {
                sdk.getTwig().i("FirebaseInstanceId.getInstance().getToken(): " + FirebaseInstanceId.getInstance().getToken());
                userInfo.setDevicePushToken(token);
            } else {
                sdk.getTwig().e("FirebaseInstanceId.getInstance().getToken() returned an IllegalStateException, you have an issue with your project configuration (google-services.json for instance)");
            }

        } else
            sdk.getTwig().i("FirebaseApp is not initialized. Make sure to call FirebaseApp.initializeApp(Context) " +
                    "before initializing the VoxeetSDK if you are planning on using FCM.");

        userInfo.setDeviceType(DeviceType.ANDROID);

        final Observable<UserTokenResponse> user = service.identify(userInfo);
        user.subscribeOn(Schedulers.newThread())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe(new Subscriber<UserTokenResponse>() {
                    @Override
                    public void onCompleted() {

                    }

                    @Override
                    public void onError(Throwable e) {
                        e.printStackTrace();
                        if(e instanceof UnknownHostException) {
                            listener.onNetworkError((UnknownHostException) e);
                        } else {
                            listener.onIdentifyError(e.getMessage());
                        }
                    }

                    @Override
                    public void onNext(UserTokenResponse userTokenResponse) {
                        sdk.getTwig().i("Successful login with id " + userTokenResponse.getId());

                        VoxeetPreferences.setId(userTokenResponse.getId());

                        VoxeetPreferences.saveLoginCookie(userTokenResponse.getUserToken());

                        listener.onIdentifySuccess(userTokenResponse, tokenResponse);

                        List<Cookie> cookies = getCookies(getBuiltServerUrl());
                        if (cookies != null && cookies.size() > 0)
                            VoxeetPreferences.saveLoginCookie(cookies.get(0).toString());
                    }
                });
    }

    /**
     * Gets cookies.
     *
     * @param url the url
     * @return the cookies
     */
    public List<Cookie> getCookies(String url) {
        for (Object o : cookieStore.entrySet()) {
            Map.Entry pair = (Map.Entry) o;
            if (((String) pair.getKey()).contains(url)) {
                return cookieStore.get(pair.getKey());
            }
        }
        return null;
    }

    /**
     * Create cookie.
     *
     * @param value the value
     * @return the string
     */
    public String createCookie(String value) {
        String url = getBuiltServerUrl();

        Cookie cookie = Cookie.parse(HttpUrl.parse(url), value);
        if (cookie != null && cookie.toString().length() > 0) {
            cookieStore.put(url, Collections.singletonList(cookie));
            return cookie.value();
        }
        return null;
    }

    /**
     * Gets client.
     *
     * @return the client
     */

    public OkHttpClient getClient() {
        return client;
    }

    /**
     * Retrieve cookie.
     *
     * @return the string
     */
    public String retrieveCookie() {
        String cookie;
        if ((cookie = VoxeetPreferences.getLoginCookie()) != null && cookie.length() > 0) {
            cookie = createCookie(cookie);
        } else {
            List<Cookie> cookies = getCookies(getBuiltServerUrl());
            if (cookies != null && cookies.size() > 0) {
                cookie = cookies.get(0).value();
                VoxeetPreferences.saveLoginCookie(cookies.get(0).toString());
            }
        }
        return cookie;
    }

    public Retrofit getRetrofit() {
        return retrofit;
    }

    /**
     * The interface Voxeet service listener.
     */
    public interface VoxeetServiceListener {

        /**
         * On identify success.
         *
         * @param response      the response
         * @param tokenResponse the token response
         */
        void onIdentifySuccess(UserTokenResponse response, TokenResponse tokenResponse);

        /**
         * On identify error.
         *
         * @param error the error
         */
        void onIdentifyError(String error);


        /**
         * On network error
         * @param error the error
         */
        void onNetworkError(UnknownHostException error);
    }

    private String getBuiltServerUrl() {

        String port = serverPort;
        if(!port.startsWith(":")) port = ":" + port;
        return serverUrl + port;
    }

    public final static class Builder {

        private Application _application;
        private VoxeetSdkTemplate _sdk;
        private String _server_url;
        private String _server_port;
        private String _app_id;
        private String _password;
        private VoxeetServiceListener _listener;
        private boolean _debug;

        public Builder() {

        }

        public Builder setApplication(Application application) {
            this._application = application;
            return this;
        }

        public Builder setVoxeetSDK(VoxeetSdkTemplate sdk) {
            this._sdk = sdk;
            return this;
        }

        public Builder setServerUrl(String serverUrl) {
            this._server_url = serverUrl;
            return this;
        }

        public Builder setServerPort(String serverPort) {
            this._server_port = serverPort;
            return this;
        }

        public Builder setAppId(String appId) {
            this._app_id = appId;
            return this;
        }

        public Builder setPassword(String password) {
            this._password = password;
            return this;
        }

        public Builder setVoxeetServiceListener(VoxeetServiceListener listener) {
            this._listener = listener;
            return this;
        }

        public Builder setDebug(boolean debug) {
            this._debug = debug;
            return this;
        }

        public VoxeetHttp build() {
            return new VoxeetHttp(this._application,
                    this._sdk,
                    this._server_url,
                    this._server_port,
                    this._app_id,
                    this._password,
                    this._listener,
                    this._debug);
        }
    }
}

==> kernel-0.9.1.5.8.3.14-sources.jar: voxeet/com/sdk/core/VoxeetHttp.java <==
package voxeet.com.sdk.core;

import android.app.Application;
import android.provider.Settings;

import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.common.base.Predicate;
import com.google.common.collect.Iterables;
import com.google.common.collect.Lists;
import com.google.firebase.iid.FirebaseInstanceId;

import java.io.IOException;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

import okhttp3.Authenticator;
import okhttp3.Cookie;
import okhttp3.CookieJar;
import okhttp3.HttpUrl;
import okhttp3.Interceptor;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.Route;
import retrofit2.Retrofit;
import retrofit2.adapter.rxjava.RxJavaCallAdapterFactory;
import rx.Observable;
import rx.Subscriber;
import rx.android.schedulers.AndroidSchedulers;
import rx.schedulers.Schedulers;
import voxeet.com.sdk.converter.JacksonConverterFactory;
import voxeet.com.sdk.core.network.IVoxeetRService;
import voxeet.com.sdk.core.preferences.VoxeetPreferences;
import voxeet.com.sdk.json.GrandTypeEvent;
import voxeet.com.sdk.json.UserInfo;
import voxeet.com.sdk.models.TokenResponse;
import voxeet.com.sdk.models.UserTokenResponse;
import voxeet.com.sdk.networking.DeviceType;
import voxeet.com.sdk.utils.Auth64;

/**
 * Created by Romain Benmansour on 4/15/16.
 */
public class VoxeetHttp {

    private static final String TAG = VoxeetHttp.class.getSimpleName();
    private final VoxeetSdkTemplate sdk;

    /**
     * The Service.
     */
    protected IVoxeetRService service;

    /**
     * The Token response.
     */
    protected TokenResponse tokenResponse;

    private Application appContext;

    private String serverUrl;

    private String serverPort;

    /**
     * The Retrofit.
     */
    public Retrofit retrofit;

    private OkHttpClient client;

    private String appId;

    private String password;

    private VoxeetServiceListener listener;

    private boolean debug = false;

    private final HashMap<String, List<Cookie>> cookieStore = new HashMap<>();

    /**
     * Instantiates a new Voxeet http.
     *
     * @param appContext the Application Context
     * @param sdk
     * @param appId      the app id
     * @param password   the password
     * @param listener   the listener
     */
    private VoxeetHttp(Application appContext, VoxeetSdkTemplate sdk, String serverUrl, String serverPort, String appId, String password, VoxeetServiceListener listener, boolean debug) {

        this.sdk = sdk;
        this.tokenResponse = null;
        this.serverUrl = serverUrl;
        this.serverPort = serverPort;
        this.appContext = appContext;

        this.debug = debug;


        this.listener = listener;

        this.appId = appId;

        this.password = password;

        this.initClient();

        this.initRetrofit();

        this.initService();
    }

    /**
     * Overrode retrofit client.
     */
    private void initClient() {
        //HttpLoggingInterceptor interceptor = new HttpLoggingInterceptor();
        //interceptor.setLevel(HttpLoggingInterceptor.Level.BODY);

        OkHttpClient.Builder builder = new OkHttpClient.Builder()
                .cookieJar(new CookieJar() {

                    @Override
                    public void saveFromResponse(HttpUrl url, List<Cookie> cookies) {
                        String base = url.scheme() + "://" + url.host() + ":" + url.port();

                        cookieStore.put(base, Lists.<Cookie>newArrayList(Iterables.filter(cookies, new Predicate<Cookie>() {
                            @Override
                            public boolean apply(Cookie input) {
                                return input != null && !input.value().equalsIgnoreCase("deleted") && new Date().before(new Date(input.expiresAt()));
                            }
                        })));
                    }

                    @Override
                    public List<Cookie> loadForRequest(HttpUrl url) {
                        String base = url.scheme() + "://" + url.host() + ":" + url.port();

                        List<Cookie> cookies = cookieStore.get(base);

                        return cookies != null ? cookies : new ArrayList<Cookie>();
                    }
                })
                .addNetworkInterceptor(new Interceptor() {
                    @Override
                    public Response intercept(Chain chain) throws IOException {
                        try {
                            if (tokenResponse == null) {
                                return chain.proceed(chain.request());
                            }


                            return chain.proceed(chain.request().newBuilder().addHeader("Authorization", "bearer " + tokenResponse.getToken()).build());
                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                        return null;
                    }
                })
                .authenticator(new Authenticator() {
                    @Override
                    public Request authenticate(Route route, Response response) throws IOException {
                        try {
                            Observable<TokenResponse> token = service.getToken(Auth64.serialize(appId, password), new GrandTypeEvent("client_credentials"));

                            tokenResponse = token.toBlocking().single();
                        } catch (Exception e) {
                            throw new IllegalStateException("Invalid credentials");
                        }

                        return response.request().newBuilder().addHeader("Authorization", "bearer " + tokenResponse.getToken()).build();
                    }
                })
                .retryOnConnectionFailure(true)
                .readTimeout(5, TimeUnit.SECONDS)
                .writeTimeout(5, TimeUnit.SECONDS);

        //if (this.debug) {
        //    builder = builder.addInterceptor(interceptor);
        //}

        client = builder.build();
    }

    private void initRetrofit() {

        retrofit = new Retrofit.Builder()
                .addCallAdapterFactory(RxJavaCallAdapterFactory.create())
                .addConverterFactory(JacksonConverterFactory.create(new ObjectMapper().disable(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES)))
                .baseUrl(getBuiltServerUrl())
                .client(client)
                .build();
    }

    private void initService() {
        service = retrofit.create(IVoxeetRService.class);
    }

    /**
     * Identify. Similar to a login
     *
     * @param userInfo the user info
     */
    public void identify(UserInfo userInfo) {

        userInfo.setDeviceIdentifier(Settings.Secure.getString(appContext.getContentResolver(), Settings.Secure.ANDROID_ID));

        if (FirebaseController.getInstance().isTokenUploadAllowed()) {
            String token = FirebaseController.getInstance().getToken();

            if(token != null) {
                sdk.getTwig().i("FirebaseInstanceId.getInstance().getToken(): " + FirebaseInstanceId.getInstance().getToken());
                userInfo.setDevicePushToken(token);
            } else {
                sdk.getTwig().e("FirebaseInstanceId.getInstance().getToken() returned an IllegalStateException, you have an issue with your project configuration (google-services.json for instance)");
            }

        } else
            sdk.getTwig().i("FirebaseApp is not initialized. Make sure to call FirebaseApp.initializeApp(Context) " +
                    "before initializing the VoxeetSDK if you are planning on using FCM.");

        userInfo.setDeviceType(DeviceType.ANDROID);

        final Observable<UserTokenResponse> user = service.identify(userInfo);
        user.subscribeOn(Schedulers.newThread())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe(new Subscriber<UserTokenResponse>() {
                    @Override
                    public void onCompleted() {

                    }

                    @Override
                    public void onError(Throwable e) {
                        e.printStackTrace();
                        if(e instanceof UnknownHostException) {
                            listener.onNetworkError((UnknownHostException) e);
                        } else {
                            listener.onIdentifyError(e.getMessage());
                        }
                    }

                    @Override
                    public void onNext(UserTokenResponse userTokenResponse) {
                        sdk.getTwig().i("Successful login with id " + userTokenResponse.getId());

                        VoxeetPreferences.setId(userTokenResponse.getId());

                        VoxeetPreferences.saveLoginCookie(userTokenResponse.getUserToken());

                        listener.onIdentifySuccess(userTokenResponse, tokenResponse);

                        List<Cookie> cookies = getCookies(getBuiltServerUrl());
                        if (cookies != null && cookies.size() > 0)
                            VoxeetPreferences.saveLoginCookie(cookies.get(0).toString());
                    }
                });
    }

    /**
     * Gets cookies.
     *
     * @param url the url
     * @return the cookies
     */
    public List<Cookie> getCookies(String url) {
        for (Object o : cookieStore.entrySet()) {
            Map.Entry pair = (Map.Entry) o;
            if (((String) pair.getKey()).contains(url)) {
                return cookieStore.get(pair.getKey());
            }
        }
        return null;
    }

    /**
     * Create cookie.
     *
     * @param value the value
     * @return the string
     */
    public String createCookie(String value) {
        String url = getBuiltServerUrl();

        Cookie cookie = Cookie.parse(HttpUrl.parse(url), value);
        if (cookie != null && cookie.toString().length() > 0) {
            cookieStore.put(url, Collections.singletonList(cookie));
            return cookie.value();
        }
        return null;
    }

    /**
     * Gets client.
     *
     * @return the client
     */

    public OkHttpClient getClient() {
        return client;
    }

    /**
     * Retrieve cookie.
     *
     * @return the string
     */
    public String retrieveCookie() {
        String cookie;
        if ((cookie = VoxeetPreferences.getLoginCookie()) != null && cookie.length() > 0) {
            cookie = createCookie(cookie);
        } else {
            List<Cookie> cookies = getCookies(getBuiltServerUrl());
            if (cookies != null && cookies.size() > 0) {
                cookie = cookies.get(0).value();
                VoxeetPreferences.saveLoginCookie(cookies.get(0).toString());
            }
        }
        return cookie;
    }

    public Retrofit getRetrofit() {
        return retrofit;
    }

    /**
     * The interface Voxeet service listener.
     */
    public interface VoxeetServiceListener {

        /**
         * On identify success.
         *
         * @param response      the response
         * @param tokenResponse the token response
         */
        void onIdentifySuccess(UserTokenResponse response, TokenResponse tokenResponse);

        /**
         * On identify error.
         *
         * @param error the error
         */
        void onIdentifyError(String error);


        /**
         * On network error
         * @param error the error
         */
        void onNetworkError(UnknownHostException error);
    }

    private String getBuiltServerUrl() {

        String port = serverPort;
        if(!port.startsWith(":")) port = ":" + port;
        return serverUrl + port;
    }

    public final static class Builder {

        private Application _application;
        private VoxeetSdkTemplate _sdk;
        private String _server_url;
        private String _server_port;
        private String _app_id;
        private String _password;
        private VoxeetServiceListener _listener;
        private boolean _debug;

        public Builder() {

        }

        public Builder setApplication(Application application) {
            this._application = application;
            return this;
        }

        public Builder setVoxeetSDK(VoxeetSdkTemplate sdk) {
            this._sdk = sdk;
            return this;
        }

        public Builder setServerUrl(String serverUrl) {
            this._server_url = serverUrl;
            return this;
        }

        public Builder setServerPort(String serverPort) {
            this._server_port = serverPort;
            return this;
        }

        public Builder setAppId(String appId) {
            this._app_id = appId;
            return this;
        }

        public Builder setPassword(String password) {
            this._password = password;
            return this;
        }

        public Builder setVoxeetServiceListener(VoxeetServiceListener listener) {
            this._listener = listener;
            return this;
        }

        public Builder setDebug(boolean debug) {
            this._debug = debug;
            return this;
        }

        public VoxeetHttp build() {
            return new VoxeetHttp(this._application,
                    this._sdk,
                    this._server_url,
                    this._server_port,
                    this._app_id,
                    this._password,
                    this._listener,
                    this._debug);
        }
    }
}
